@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef MODULE_H
-#define MODULE_H
+#pragma once
 
 #include "kactivitymanagerd_plugin_export.h"
 
@@ -43,5 +42,3 @@ public:
 private:
     D_PTR;
 };
-
-#endif // MODULE_H
