@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef KSMSERVER_H
-#define KSMSERVER_H
+#pragma once
 
 // Qt
 #include <QObject>
@@ -39,5 +38,3 @@ Q_SIGNALS:
 private:
     D_PTR;
 };
-
-#endif // KSMSERVER_H
