@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PLUGINS_GLOBAL_TEMPLATES_PLUGIN_H
-#define PLUGINS_GLOBAL_TEMPLATES_PLUGIN_H
+#pragma once
 
 #include <Plugin.h>
 
@@ -15,7 +14,7 @@ class TemplatesPlugin : public Plugin
     Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Templates")
 
 public:
-    explicit TemplatesPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit TemplatesPlugin(QObject *parent);
     ~TemplatesPlugin() override;
 
     bool init(QHash<QString, QObject *> &modules) override;
@@ -30,5 +29,3 @@ public Q_SLOTS:
 private:
     QObject *m_activities;
 };
-
-#endif // PLUGINS_GLOBAL_TEMPLATES_PLUGIN_H
