@@ -15,18 +15,16 @@
 #include <KGlobalAccel>
 #include <KLocalizedString>
 
-K_PLUGIN_CLASS_WITH_JSON(GlobalShortcutsPlugin, "kactivitymanagerd-plugin-globalshortcuts.json")
+K_PLUGIN_CLASS(GlobalShortcutsPlugin)
 
 const auto objectNamePattern = QStringLiteral("switch-to-activity-%1");
 const auto objectNamePatternLength = objectNamePattern.length() - 2;
 
-GlobalShortcutsPlugin::GlobalShortcutsPlugin(QObject *parent, const QVariantList &args)
+GlobalShortcutsPlugin::GlobalShortcutsPlugin(QObject *parent)
     : Plugin(parent)
     , m_activitiesService(nullptr)
     , m_actionCollection(new KActionCollection(this))
 {
-    Q_UNUSED(args);
-
     m_actionCollection->setComponentName("ActivityManager");
     m_actionCollection->setComponentDisplayName(i18n("Activity Manager"));
 }
@@ -42,7 +40,7 @@ bool GlobalShortcutsPlugin::init(QHash<QString, QObject *> &modules)
 
     m_activitiesService = modules["activities"];
 
-    m_activitiesList = Plugin::retrieve<QStringList>(m_activitiesService, "ListActivities", "QStringList");
+    m_activitiesList = Plugin::retrieve<QStringList>(m_activitiesService, "ListActivities");
 
     for (const auto &activity : m_activitiesList) {
         activityAdded(activity);
@@ -72,7 +70,7 @@ void GlobalShortcutsPlugin::activityAdded(const QString &activity)
     action->setText(i18nc("@action", "Switch to activity \"%1\"", activityName(activity)));
     KGlobalAccel::setGlobalShortcut(action, QList<QKeySequence>{});
 
-    connect(action, &QAction::triggered, [this, activity]() {
+    connect(action, &QAction::triggered, this, [this, activity]() {
         Q_EMIT currentActivityChanged(activity);
     });
 
@@ -112,7 +110,9 @@ void GlobalShortcutsPlugin::activityChanged(const QString &activity)
 
 QString GlobalShortcutsPlugin::activityName(const QString &activity) const
 {
-    return Plugin::retrieve<QString>(m_activitiesService, "ActivityName", "QString", Q_ARG(QString, activity));
+    return Plugin::retrieve<QString>(m_activitiesService, "ActivityName", Q_ARG(QString, activity));
 }
 
 #include "GlobalShortcutsPlugin.moc"
+
+#include "moc_GlobalShortcutsPlugin.cpp"
