@@ -79,7 +79,7 @@ RemoteMatches ActivityRunner::Match(const QString &query)
 QVariantMap ActivityRunner::Config()
 {
     return {
-        {"MinLetterCount", qMin(m_keyword.count(), m_keywordi18n.count())},
+        {"MinLetterCount", qMin(m_keyword.length(), m_keywordi18n.length())},
         {"MatchRegex", '^' + m_keyword + '|' + m_keywordi18n},
     };
 }
